Enum serde_cbor::error::Error
[−]
[src]
pub enum Error {
Syntax,
Io(Error),
FromUtf8(FromUtf8Error),
Custom(String),
Eof,
StopCode,
TrailingBytes,
// some variants omitted
}Represents all possible errors that can occur when serializing or deserializing a value.
Variants
SyntaxThe CBOR value had a syntactic error.
Io(Error)Some IO error occured when processing a value.
FromUtf8(FromUtf8Error)Some error occured while converting a string.
Custom(String)A custom error provided by serde occured.
EofThe data source contains not enough bytes to parse a value.
StopCodeBreak stop code encountered.
TrailingBytesThe data source contains trailing bytes after all values were read.